
# This file was generated by 'versioneer.py' (0.18) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2021-04-12T11:49:45+0200",
 "dirty": false,
 "error": null,
 "full-revisionid": "3a8c263f86b2d8b2095684e5b9b787609b0e1b34",
 "version": "1.7.3"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
